
require(afex) # needed for ANOVA and loading reshape2
require(reshape2) # may be required for transforming the data prior the analysis.
require(plotrix) # needed for plotting

##################
## Experiment 1 ##
##################

d.in <- read.table("experiment1.txt", header = TRUE)
### Variables:
# VP = Participant ID
# Bed = condition (1 = deductive, 2 = inductive/probabilistic)
# C = content/conditional:
#     1 = Wenn Wasser auf ein Lagerfeuer gegossen wurde, dann geht es aus.
#     2 = Wenn eine Person nass ist, dann ist sie in ein Schwimmbecken gefallen.
#     3 = Wenn eine Person viel Salz gegessen hat, dann ist sie durstig.
#     4 = Wenn eine Person sich verschluckt hat, dann hustet sie.
# direction: 1 = original; 2 = reversed


mean(d.in$age)

d.direction <- melt(d.in, id.vars=c("VP", "Bed"), measure.vars=c("C1_R", "C2_R", "C3_R", "C4_R"))
d.direction$content <- factor(substr(as.character(d.direction$variable),1,2))
d.direction <- within(d.direction, {
  variable <- NULL
  direction <- value
  value <- NULL
})
d.responses <- melt(d.in, id.vars=c("VP", "Bed"), measure.vars= paste0(rep(paste0("C", 1:4), each = 4), "_", c("MP", "AC", "MT", "DA"), "_1"))
d.responses$content <- factor(substr(d.responses$variable, 1, 2))
d.responses$inference <- factor(substr(d.responses$variable, 4, 5))
d.responses$variable <- NULL
dl <- merge(d.responses, d.direction)
dl <- within(dl, {
  VP <- factor(VP)
  instruction <- factor(Bed)
  type <- factor(direction)
  problem <- inference
})
dl$what <- factor(ifelse(dl$inference %in% c("MP", "AC"), "affirmation", "denial"))
head(dl)
str(dl)

## ANOVAs:
ez.glm("VP", "value", dl[dl$what == "affirmation",], within = c("problem", "type"), between = "instruction", args.return=(es = "pes"))
ez.glm("VP", "value", dl[dl$what == "denial",], within = c("problem", "type"), between = "instruction", args.return=(es = "pes"))

### plots

#x-axis var:
dl$x <- factor(dl$problem:dl$type, levels = c("MP:1", "MP:2", "AC:2", "AC:1", "MT:1", "MT:2", "DA:2", "DA:1"))

par(mfrow=c(1,2))
raw.means.plot2(dl[dl$what == "affirmation",], "VP", "instruction", "x", "value", main = "Affirmation Problems")
raw.means.plot2(dl[dl$what == "denial",], "VP", "instruction", "x", "value", main = "Denial Problems")


##################
## Experiment 2 ##
##################

d2.in <- read.table("experiment2.txt", header = TRUE, fileEncoding="UTF-8")
### Variables:
# Bed = condition (1 = deductive, 2 = inductive/probabilistic)
# C = content/conditional:
#     1 = Wenn eine Person in ein Schwimmbecken gefallen ist, dann ist sie nass.
#     2 = Wenn ein Hund Fl?he hat, dann kratzt er sich hin und wieder.
#     3 = Wenn eine Seifenblase mit einer Nadel gestochen wurde, dann platzt sie.
#     4 = Wenn ein M?dchen Geschlechtsverkehr vollzogen hat, dann ist es schwanger.
#     5 = Wenn eine Pflanze ausreichend gegossen wird, dann bleibt sie gr?n.
#     6 = Wenn sich eine Person die Z?hne putzt, dann bekommt sie KEIN Karies.
#     7 = Wenn eine Person viel Cola trinkt, dann nimmt sie an Gewicht zu.
#     8 = Wenn eine Person die Klimaanlage angeschaltet hat, dann fr?stelt sie.
#     9 = Wenn eine Person viel lernt, dann wird sie in der Klausur eine gute Note erhalten.

d2.fin <- d2.in[ d2.in$excl_reason == "", ]
head(d2.fin)
str(d2.in)

d2.responses <- melt(d2.fin, id.vars=c("VP", "Bed"), measure.vars= paste0(rep(paste0("C", 1:9), each = 4), "_", c("MP", "AC", "MT", "DA")))
head(d2.responses)
d2.responses$content <- factor(substr(d2.responses$variable, 1, 2))
d2.responses$problem <- factor(substr(d2.responses$variable, 4, 5))
d2.responses$variable <- NULL
d2.responses$what <- factor(ifelse(d2.responses$problem %in% c("MP", "AC"), "affirmation", "denial"))
d2.responses$type <- factor(ifelse(d2.responses$content %in% paste0("C",1:3), "prological", ifelse(d2.responses$content %in% paste0("C",4:6), "counterlogical", "neutral")))
head(d2.responses)

## ANOVA
ez.glm("VP", "value", d2.responses[d2.responses$what == "affirmation",], between = "Bed", within = c("type", "problem"))
ez.glm("VP", "value", d2.responses[d2.responses$what == "denial",], between = "Bed", within = c("type", "problem"))

## plots:
## Please note that for the denial inferences the plot in the original manuscript was not entirely correct.
## Specifically, the values for "DA - invalid & neutral" appear twice. Once at the correct location and once for "DA - invalid & plausible".
## The plot below is correct and does not show this error. 
## The zip file also includes a new version of Figure 4.

d2_aff <- droplevels(d2.responses[d2.responses$what == "affirmation",])
d2_den <- droplevels(d2.responses[d2.responses$what == "denial",])

d2_aff$x <- factor(d2_aff$problem:d2_aff$type, levels = c("MP:prological", "MP:neutral", "MP:counterlogical", "AC:counterlogical", "AC:neutral", "AC:prological"))

d2_den$x <- factor(d2_den$problem:d2_den$type, levels = c("MT:prological", "MT:neutral", "MT:counterlogical", "DA:counterlogical", "DA:neutral", "DA:prological"))


raw.means.plot2(d2_aff, "VP", "Bed", "x", "value", main = "Affirmation Problems")
raw.means.plot2(d2_den, "VP", "Bed", "x", "value", main = "Denial Problems")


# specific analysis:
d2_agg <- aggregate(value ~ VP + Bed + problem + what + type, d2.responses, mean)

### analysis of affirmation trials:
# cross over interaction:
compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MP" & d2_agg$Bed == "deduktiv","value"], 
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="AC" & d2_agg$Bed == "deduktiv","value"], 
  paired = TRUE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MP" & d2_agg$Bed == "induktiv","value"], 
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="AC" & d2_agg$Bed == "induktiv","value"], 
  paired = TRUE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MP" & d2_agg$Bed == "deduktiv","value"],
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MP" & d2_agg$Bed == "induktiv","value"], 
  paired = FALSE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="AC" & d2_agg$Bed == "deduktiv","value"],
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="AC" & d2_agg$Bed == "induktiv","value"],
  paired = FALSE)

### analysis of denial trials:
# cross over interaction:
compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MT" & d2_agg$Bed == "deduktiv","value"], 
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="DA" & d2_agg$Bed == "deduktiv","value"], 
  paired = TRUE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MT" & d2_agg$Bed == "induktiv","value"], 
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="DA" & d2_agg$Bed == "induktiv","value"], 
  paired = TRUE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MT" & d2_agg$Bed == "deduktiv","value"],
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="MT" & d2_agg$Bed == "induktiv","value"], 
  paired = FALSE)

compare.2.vectors(
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="DA" & d2_agg$Bed == "deduktiv","value"],
  d2_agg[d2_agg$type == "counterlogical" & d2_agg$problem=="DA" & d2_agg$Bed == "induktiv","value"],
  paired = FALSE)
